==> dynamic-repository-1.1.1-sources.jar: io/overcoded/repository/annotation/processor/supplier/DynamicRepositorySupplier.java <==
package io.overcoded.repository.annotation.processor.supplier;

import io.overcoded.repository.annotation.DynamicRepository;
import io.overcoded.repository.annotation.processor.domain.ElementCollection;
import io.overcoded.repository.annotation.processor.domain.RepositoryData;

import java.util.HashSet;

/**
 * @author Diana Ladanyi
 * @author Adam Belak
 */
class DynamicRepositorySupplier extends AbstractSupplier implements Supplier {
    @Override
    public RepositoryData execute(ElementCollection elementCollection, RepositoryData repositoryData) {
        repositoryData.setFindMethods(new HashSet<>());
        repositoryData.setCountMethods(new HashSet<>());
        repositoryData.setFindOneMethods(new HashSet<>());
        repositoryData.setProjectionMethods(new HashSet<>());
        repositoryData.setSuffix(elementCollection.getDynamicRepositoryElement().getAnnotation(DynamicRepository.class).suffix());
        repositoryData.setResourcePath(elementCollection.getDynamicRepositoryElement().getAnnotation(DynamicRepository.class).resourcePath());
        repositoryData.setRestResourceEnabled(elementCollection.getDynamicRepositoryElement().getAnnotation(DynamicRepository.class).restResourceEnabled());
        repositoryData.setEntityType(elementCollection.getDynamicRepositoryElement().getSimpleName().toString());
        repositoryData.setPackageName(elementCollection.getDynamicRepositoryElement().getEnclosingElement().toString());
        return super.execute(elementCollection, repositoryData);
    }
}

==> dynamic-repository-1.1.2-sources.jar: io/overcoded/repository/annotation/processor/supplier/DynamicRepositorySupplier.java <==
package io.overcoded.repository.annotation.processor.supplier;

import io.overcoded.repository.annotation.DynamicRepository;
import io.overcoded.repository.annotation.processor.domain.ElementCollection;
import io.overcoded.repository.annotation.processor.domain.RepositoryData;

import java.util.HashSet;

/**
 * @author Diana Ladanyi
 * @author Adam Belak
 */
class DynamicRepositorySupplier extends AbstractSupplier implements Supplier {
    @Override
    public RepositoryData execute(ElementCollection elementCollection, RepositoryData repositoryData) {
        repositoryData.setFindMethods(new HashSet<>());
        repositoryData.setCountMethods(new HashSet<>());
        repositoryData.setFindOneMethods(new HashSet<>());
        repositoryData.setProjectedFields(new HashSet<>());
        repositoryData.setSuffix(elementCollection.getDynamicRepositoryElement().getAnnotation(DynamicRepository.class).suffix());
        repositoryData.setResourcePath(elementCollection.getDynamicRepositoryElement().getAnnotation(DynamicRepository.class).resourcePath());
        repositoryData.setRestResourceEnabled(elementCollection.getDynamicRepositoryElement().getAnnotation(DynamicRepository.class).restResourceEnabled());
        repositoryData.setEntityType(elementCollection.getDynamicRepositoryElement().getSimpleName().toString());
        repositoryData.setPackageName(elementCollection.getDynamicRepositoryElement().getEnclosingElement().toString());
        return super.execute(elementCollection, repositoryData);
    }
}
